Modules
- auth
- branch
- browse
- completions
- pr
- pr_
build - pr_
comments - pr_list
- pr_mine
- pr_
retarget bb pr retarget: point an open pull request at a different destination branch.- pr_
reviewers - project
- repo
- skill
- update
bb pr retarget: point an open pull request at a different destination branch.