Module completions

Module completions 

Functions

generate
Writes a completion script for shell to stdout. The command factory is supplied by the caller so this module does not depend on the binary’s types.