pub fn build_payload(args: &CommentArgs, body: &str) -> Result<Value>Expand description
Builds the request body, rejecting flag combinations the API cannot honour.
pub fn build_payload(args: &CommentArgs, body: &str) -> Result<Value>Builds the request body, rejecting flag combinations the API cannot honour.