pub fn tone_for(state: BuildState) -> ToneExpand description
The single source of truth for how a build state maps to a colour intent.
pub fn tone_for(state: BuildState) -> ToneThe single source of truth for how a build state maps to a colour intent.