pub fn generate<C: CommandFactory>(shell: Shell)Expand description
Writes a completion script for shell to stdout. The command factory is
supplied by the caller so this module does not depend on the binary’s types.
pub fn generate<C: CommandFactory>(shell: Shell)Writes a completion script for shell to stdout. The command factory is
supplied by the caller so this module does not depend on the binary’s types.