pub fn asset_names(tag: &str, triple: &str) -> (String, String)Expand description
Archive and checksum asset names for a tag and triple. Must match the
archive: pattern in .github/workflows/release.yml, which is
bbcloud-$tag-$target; cargo-binstall’s default templates key off the
crate name, which is why the prefix is bbcloud and not the binary name.